@@ -63,8 +63,11 @@ extract_gof <- function(model, fmt, gof_map = NULL) {
         }
 
         # reshape
-        out <- gof %>%
-               tidyr::pivot_longer(cols = 1:ncol(.), names_to = 'term')
+        out <- suppressWarnings(tidyr::pivot_longer(gof, cols = 1:ncol(gof), names_to = 'term'))
+
+
+#        out <- gof %>%
+#               tidyr::pivot_longer(cols = 1:ncol(.), names_to = 'term')
 
     } else { # all gof are excluded return an empty tibble (needs character to match merge type)
         out <- tibble::tibble(term = NA_character_, value = NA_character_) %>% tidyr::drop_na()
